@@ -608,7 +608,7 @@ def parse_input_names(input_notebook_filenames, debug):
     if notebook_filenames == []:
         print(RED, "At least one argument (one or more ipynb filenames)",
               "required\n", NC)
-        assert False
+        raise AssertionError
 
     # Check if files exist, assert error if not
     files_exist = True
@@ -621,7 +621,7 @@ def parse_input_names(input_notebook_filenames, debug):
 
     if not files_exist:
         print(RED, "One more more files do not exist\n", NC)
-        assert False
+        raise AssertionError
 
     return notebook_filenames
 
@@ -667,7 +667,7 @@ def parse_compare_input(args_compare, args_execute, debug):
             print("    jnbv file1.ipynb --kernel_name python3 --execute ",
                   "--compare\n")
             print(RED, "Assertion Error:", NC)
-            assert False
+            raise AssertionError
 
     # If a file name has been given check that it exists
     if isinstance(args_compare, str):
@@ -676,7 +676,7 @@ def parse_compare_input(args_compare, args_execute, debug):
             debug and print(GREEN, args_compare, "exists", NC)
         else:
             print(RED, args_compare, "does not exist\n", NC)
-            assert False
+            raise AssertionError
 
     return args_compare
 
